#
# spec file for package icu (Version 4.2)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           icu
BuildRequires:  gcc-c++
License:        IBM PL
Group:          System/Libraries
Version:        4.2
Release:        2
Requires:       libicu = %{version}
Url:            http://ibm.com/software/globalization/icu
Source0:        icu4c-4_2-src.tar.bz2
Source1:        icu4c-4_2-docs.tar.bz2
Source3:        SuSEconfig.icu
# PATCH-FIX-OPENSUSE icu-remove-datetime.patch vuntz@novell.com -- Do not put date/time in icu-config (needed for build-compare)
Patch99:        icu-remove-datetime.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        International Components for Unicode

%description
ICU is a set of C and C++ libraries that provides robust and
full-featured Unicode and locale support. The library provides calendar
support, conversions for many character sets, language sensitive
collation, date and time formatting, support for many locales, message
catalogs and resources, message formatting, normalization, number and
currency formatting, time zone support, transliteration, and word,
line, and sentence breaking, etc.

This package contains the Unicode character database and derived
properties along with converters and time zone data.

This package contains the runtime libraries for ICU. It does not
contain any of the data files needed at runtime and present in the icu
and icu-locales packages.



Authors:
--------
    The ICU project, International Business Machines (IBM) and Others.  <icu@oss.software.ibm.com>

%package -n libicu
License:        IBM PL
Summary:        International Components for Unicode (development files)
Group:          Development/Libraries/C and C++
# bug437293
%ifarch ppc64
Obsoletes:      libicu-64bit
%endif
#
Provides:       libicu17 libicu22 libicu26 libicu30 libicu32 libicu34
Obsoletes:      libicu17 libicu22 libicu26 libicu30 libicu32 libicu34 icu-i18ndata
Requires:       timezone

%description -n libicu
ICU is a set of C and C++ libraries that provides robust and
full-featured Unicode support. This package contains the runtime
libraries for ICU. It does not contain any of the data files needed at
runtime and present in the `icu' and `icu-locales` packages.



Authors:
--------
    The ICU project, International Business Machines (IBM) and Others.  <icu@oss.software.ibm.com>

%package -n libicu-devel
License:        IBM PL
Summary:        International Components for Unicode (development files)
Group:          Development/Libraries/C and C++
# bug437293
%ifarch ppc64
Obsoletes:      libicu-devel-64bit
%endif
#
Requires:       libicu = %{version}

%description -n libicu-devel
ICU is a C++ and C library that provides robust and full-featured
Unicode support. This package contains the development files for ICU.



Authors:
--------
    The ICU project, International Business Machines (IBM) and Others.  <icu@oss.software.ibm.com>

%package -n libicu-doc
License:        IBM PL
Summary:        International Components for Unicode  (html documentation)
Group:          Development/Libraries/C and C++

%description -n libicu-doc
ICU is a C++ and C library that provides robust and full-featured
Unicode support. This package contains the html documentation.



Authors:
--------
    The ICU project, International Business Machines (IBM) and Others.  <icu@oss.software.ibm.com>

%package -n icu-data
License:        IBM PL
Summary:        International Components for Unicode (Sources for the Data in ICU)
Group:          System/Libraries
Requires:       libicu >= %{version}

%description -n icu-data
ICU is a C++ and C library that provides robust and full-featured
Unicode support. This package contains the source files for the data
found in the "icu" package.

This data describes the Unicode data (normative and informative) and
also all the table-based converters provided in the ICU distribution.

This package contains uncompiled source data. Precompiled data is in
the `libicu%{version}' package.



Authors:
--------
    The ICU project, International Business Machines (IBM) and Others.  <icu@oss.software.ibm.com>

%prep
%setup -q -n icu -a1
%patch99 -p1

%build
cd source
rm -f config.cache
%{?suse_update_config:%{suse_update_config -f }}
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$CXXFLAGS -DICU_DATA_DIR='/usr/share/icu/4.0/'"
%configure --disable-static --with-pic\
    --enable-shared \
    --without-samples
%{__make} %{?jobs:-j%jobs}

%install
find . -name CVS -type d | xargs rm -rf
cd source
make DESTDIR=$RPM_BUILD_ROOT install
# to extract debug info
chmod a+rx $RPM_BUILD_ROOT%{_libdir}/*.so.*
# install uncompiled source data:
mkdir -p $RPM_BUILD_ROOT/usr/share/icu/%{version}/unidata
install -m 644 data/unidata/*.txt $RPM_BUILD_ROOT/%{_datadir}/icu/%{version}/unidata
ln -s unidata/UnicodeData.txt $RPM_BUILD_ROOT/%{_datadir}/icu/%{version}/
# run test suite:
#pushd data
#ln -sf build/*.cnv build/*.res build/*.dat build/*.brk .
#popd
#make check || echo "make check returned $?, ignored."
#popd
mkdir -p $RPM_BUILD_ROOT/sbin/conf.d/
sed -e "s/@ICUVERSION@/%{version}/g" < ${RPM_SOURCE_DIR}/SuSEconfig.icu > ./SuSEconfig.icu
install -m 755 ./SuSEconfig.icu $RPM_BUILD_ROOT/sbin/conf.d/
rm $RPM_BUILD_ROOT/%{_datadir}/icu/%{version}/license.html
rm $RPM_BUILD_ROOT/%{_datadir}/icu/%{version}/install-sh

%clean
rm -rf $RPM_BUILD_ROOT

%post -n libicu -p /sbin/ldconfig

%postun -n libicu -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc license.html readme.html
%dir %{_libdir}/icu/
%dir %{_libdir}/icu/%{version}
%{_libdir}/icu/current
%{_bindir}/derb
%{_bindir}/genbrk
%{_bindir}/gencfu
%{_bindir}/gencnval
%{_bindir}/genrb
%{_bindir}/genctd
%{_bindir}/makeconv
%{_bindir}/pkgdata
%{_bindir}/uconv
/usr/sbin/*
%{_mandir}/*/*
/sbin/conf.d/SuSEconfig.icu

%files -n libicu
%defattr(-, root, root)
%attr (755, root, root) %{_libdir}/lib*.so.*

%files -n libicu-devel
%defattr(-, root, root)
%{_libdir}/lib*.so
%{_includedir}/unicode/
%{_includedir}/layout/
%{_libdir}/icu/%{version}/Makefile.inc
%{_libdir}/icu/%{version}/pkgdata.inc
%{_libdir}/icu/Makefile.inc
%{_libdir}/icu/pkgdata.inc
%{_bindir}/icu-config
%dir %{_datadir}/icu
%dir %{_datadir}/icu/%{version}
%{_datadir}/icu/%{version}/mkinstalldirs
%{_datadir}/icu/%{version}/config/

%files -n libicu-doc
%defattr(-, root, root)
%doc html/

%files -n icu-data
%defattr(-, root, root)
%{_datadir}/icu/%{version}/unidata/
%{_datadir}/icu/%{version}/UnicodeData.txt

%changelog
